Crate tree_sitter_xdy

Crate tree_sitter_xdy 

This crate provides xDy language support for the tree-sitter parsing library.

Typically, you will use the language function to add this language to a tree-sitter Parser, and then use the parser to parse some code:

let code = r#"0"#;
let mut parser = tree_sitter::Parser::new();
parser
    .set_language(&tree_sitter_xdy::language())
    .expect("Error loading xDy grammar");
let tree = parser.parse(code, None).unwrap();
assert!(!tree.root_node().has_error());

Constants

NODE_TYPES
The content of the node-types.json file for this grammar.

Functions

language
Get the tree-sitter Language for this grammar.